@@ -206,6 +206,8 @@ def r2a(rasterfn,dtype = None):
     ----------
     rasterfn : String
         raster file path.
+    dtype : String
+        date type: int, int8, float, float32, etc.
 
     Returns
     -------
@@ -215,11 +217,13 @@ def r2a(rasterfn,dtype = None):
     '''
     if dtype==None:
         raster = gdal.Open(rasterfn)
-        band = raster.GetRasterBand(1)
+        ra = raster.GetRasterBand(1).ReadAsArray()
     else:
         raster = gdal.Open(rasterfn)
-        band = raster.GetRasterBand(1).astype(dtype)
-    return band.ReadAsArray()
+        ra = raster.GetRasterBand(1).ReadAsArray()
+        ra = ra.astype(dtype)
+    return ra
+
 
 def n2a(ncfile,var_name):
     '''
